@@ -3,7 +3,7 @@ function(y,L)
 {
 numvar<-ncol(y)
 H<-matrix(runif(L*numvar,-1,1),numvar,L)
-psi<-var(y)*0.1
+psi<-var(y)
 
 output<-list(psi=psi,H=H)
 }
